lcor.ci: confidence intervals for the Lancaster correlation coefficient
Description
Computes confidence intervals for the Lancaster correlation coefficient.
Lancaster correlation is a bivariate measures of dependence.
Usage
lcor.ci(x, y = NULL, conf.level = 0.95, type = c("rank", "linear"), con = TRUE,
R = 1000, method = c("plugin", "boot", "pretest"))
Value
lcor.ci returns a vector containing the lower and upper limits of the confidence interval.
Arguments
x
a numeric vector, or a matrix or data frame with two columns.
y
NULL (default) or a vector with same length as x.
conf.level
confidence level of the interval.
type
a character string indicating which lancaster correlation is to be computed. One of "rank" (default), or "linear": can be abbreviated.
con
logical; if TRUE (default), conservative asymptotic confidence intervals are computed.
R
number of bootstrap replications.
method
a character string indicating how the asymptotic covariance matrix is computed if type ="linear". One of "plugin" (default), "boot" or "symmetric": can be abbreviated.
Author
Hajo Holzmann, Bernhard Klar
References
Holzmann, Klar (2024) Lancester correlation - a new dependence
measure linked to maximum correlation. arXiv:2303.17872